<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>ZoomIn</name>
    <message>
        <location filename="../ZoomInInit.js" line="+2"/>
        <source>Zoom &amp;In</source>
        <translation>&amp;Přiblížit</translation>
    </message>
</context>
</TS>
